'use strict';

var pluginKubernetesCommon = require('@backstage/plugin-kubernetes-common');
var constants = require('../constants.cjs.js');

const defaultEksClusterEntityTransformer = async (cluster, accountId) => {
  const { arn, endpoint, certificateAuthority, name } = cluster;
  const normalizedName = normalizeName(name);
  return {
    apiVersion: "backstage.io/v1alpha1",
    kind: "Resource",
    metadata: {
      annotations: {
        [constants.ANNOTATION_AWS_ACCOUNT_ID]: accountId,
        [constants.ANNOTATION_AWS_ARN]: arn || "",
        [pluginKubernetesCommon.ANNOTATION_KUBERNETES_API_SERVER]: endpoint || "",
        [pluginKubernetesCommon.ANNOTATION_KUBERNETES_API_SERVER_CA]: certificateAuthority?.data || "",
        [pluginKubernetesCommon.ANNOTATION_KUBERNETES_AUTH_PROVIDER]: "aws",
        [pluginKubernetesCommon.ANNOTATION_KUBERNETES_AWS_CLUSTER_ID]: normalizedName
      },
      name: normalizedName,
      namespace: "default"
    },
    spec: {
      type: "kubernetes-cluster",
      owner: "unknown"
    }
  };
};
function normalizeName(name) {
  return name.trim().toLocaleLowerCase("en-US").replace(/[^a-zA-Z0-9\-]/g, "-");
}

exports.defaultEksClusterEntityTransformer = defaultEksClusterEntityTransformer;
//# sourceMappingURL=defaultTransformers.cjs.js.map
