'use strict';

var backendPluginApi = require('@backstage/backend-plugin-api');

const DEFAULT_PROVIDER_ID = "default";
function readAwsS3Configs(config) {
  const configs = [];
  const providerConfigs = config.getOptionalConfig("catalog.providers.awsS3");
  if (!providerConfigs) {
    return configs;
  }
  if (providerConfigs.has("bucketName")) {
    configs.push(readAwsS3Config(DEFAULT_PROVIDER_ID, providerConfigs));
    return configs;
  }
  for (const id of providerConfigs.keys()) {
    configs.push(readAwsS3Config(id, providerConfigs.getConfig(id)));
  }
  return configs;
}
function readAwsS3Config(id, config) {
  const bucketName = config.getString("bucketName");
  const region = config.getOptionalString("region");
  const prefix = config.getOptionalString("prefix");
  const accountId = config.getOptionalString("accountId");
  const schedule = config.has("schedule") ? backendPluginApi.readSchedulerServiceTaskScheduleDefinitionFromConfig(
    config.getConfig("schedule")
  ) : void 0;
  return {
    id,
    bucketName,
    region,
    prefix,
    schedule,
    accountId
  };
}

exports.readAwsS3Configs = readAwsS3Configs;
//# sourceMappingURL=config.cjs.js.map
